#
# spec file for package pix
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pix
Version:        2.6.3
Release:        bp155.2.17
Summary:        Image viewer and browser utility
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://github.com/linuxmint/pix
Source:         https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
#PATCH-FIX-UPSTREAM dead_mozay@opensuse.org - exiv2 0.27 Exiv2::Error has changed from an int to an Exiv2::ErrorCode enum
Patch0:         pix-exiv2-error.patch
BuildRequires:  bison
BuildRequires:  dcraw
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  itstool
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(clutter-1.0) >= 1.0.0
BuildRequires:  pkgconfig(clutter-gtk-1.0) >= 1.0.0
BuildRequires:  pkgconfig(exiv2) >= 0.21
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.34.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libbrasero-burn3) >= 3.2.0
# Disabled until upstreams ports to current libopenraw
#BuildRequires:  pkgconfig(libopenraw-0.1)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.34.0
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-gnome-2.4) >= 2.36.0
BuildRequires:  pkgconfig(libwebp) >= 0.2.0
BuildRequires:  pkgconfig(sm) >= 1.0.0
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(zlib)
Requires:       xapps-common
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
pix lets you browse your hard disk, showing you thumbnails of
image files.
It also lets you view single files (including GIF animations), add
comments to images, organise images in catalogs, print images, view
slide shows, set your desktop background, and more.

%lang_package

%package devel
Summary:        Image viewer and browser utility -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
pix lets you browse your hard disk, showing you thumbnails of
image files.
It also lets you view single files (including GIF animations), add
comments to images, organise images in catalogs, print images, view
slide shows, set your desktop background, and more.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 gnome-autogen.sh
export SUID_CFLAGS=-fPIE
export SUID_LDFLAGS=-pie
%configure\
  --disable-static       \
  --disable-silent-rules \
  --enable-libraw        \
  --with-smclient=xsmp
make %{?_smp_mflags} V=1

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}
%suse_update_desktop_file %{name}-import
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc README debian/changelog
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*.*
%{_datadir}/glib-2.0/schemas/*%{name}*.gschema.xml
%{_datadir}/glib-2.0/schemas/*%{name}.enums.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}-*/
%{_datadir}/aclocal/%{name}.m4
%{_libdir}/pkgconfig/%{name}-*.pc

%changelog
* Sat Jan  2 2021 andy great <andythe_great@pm.me>
- Update to version 2.6.3.
  * l10n: Update translations
* Wed Dec 30 2020 andy great <andythe_great@pm.me>
- Update to version 2.6.2.
  * l10n: Update translations
- Updates for version 2.6.1.
  * l10n: Update translations
* Mon Dec  7 2020 andy great <andythe_great@pm.me>
- Update to version 2.6.0.
  * Fix picture greyed out even if not selected
  * Added backspace to list of hot keys for fullscreen mode
  * Added line on how to remove image from selection
  * Added Rating to filter list for ticket #104
  * gth-browser.c: Improve handling of invalid uris.
  * Use debhelper 10 to allow parallel (-j) make jobs.
  * Implements #74. Allow for override of permanent delete message
  * Add favorites:/// to the sidebar file browser.
  * l10n: Update POT
  * Fix pix crashes with some XCF files.
* Sun Sep 27 2020 andy great <andythe_great@pm.me>
- Update to version 2.4.11.
  * Fix app version
- Update since 2.2.0.
  * l10n: Update translations
  * Use the new xapp diaporama-symbolic icon
  * Packaging: Remove gnome-doc-utils
  * Remove dependency on scrollkeeper
  * cairo_io/cairo-image-surface-xcf.c: Initialize some variables.
  * various: check for valid surfaces after creating them.
  * image viewer: do not try do paint surfaces with invalid size
  * gth-image: allow to set null surfaces
  * check whether the scaled surface is null before using it
  * cairo scale: do not create images with invalid dimensions
  * jpeg loader: do not scan more than output_height lines
  * jpeg loader: error if the orientation swaps width and height
  * jpeg loader: call alloc_sarray before jpeg_start_decompress
  * jpeg loader: crash when the original size is too big for a
    cairo surface
  * gth-image-print-job.c: Use better spinbutton settings, and
    allow adjustment to two decimal places when inch units are
    selected.
  * gth-image-print-job.c: Update spin button settings when the
    view is first created, not just when the units combobox is
    changed.
  * print settings: Keep images centered until explicitly moved off
    center
  * print settings: Remove 'pixel' option in units selector.
  * print settings: Fix inch-to-metric conversion
  * Deletion dialogs: Highlight OK button by default
  * Browser: Replace edit icon
  * Viewer: Switch to high zoom-quality by default
  * Remove gconf usage
  * Make the slideshow feature respect the preferences zoom quality
    setting instead of always being low
- Remove gnome-doc-utils dependency
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.0
  * Patches rebase and merged
  * Add autogen file and amend Install (#64)
  * Fix exiv2 issues (https://github.com/linuxmint/pix/issues/70) (#71)
  * Add Ctrl+W and Ctrl+Q shortcuts
  * l10n: Update translations
- drop pix-exiv2-xmp_hpp.patch, upstream fixed.
* Fri Jun 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(libopenraw-1.0) with disabled
  pkgconfig(libopenraw-0.1) BuildRequires until upstream ports to
  current libopenraw.
* Mon Feb  4 2019 Marguerite Su <i@marguerite.su>
- Update to version 2.0.3
  * Update translations.
- Changes in 2.0.2
  * image_viewer/gth-image-viewer-page.c: Use ctrl-v for Paste
    Image shortcut.
- Changes in 2.0.0
  * Use icon for keyboard shortcuts help entry
- Add pix-exiv2-xmp_hpp.patch
  * xmp.hpp was renamed to xmp_exiv2.hpp
- Add pix-exiv2-error.patch
  * exiv2 0.27 Exiv2::Error has changed from an int to an
    Exiv2::ErrorCode enum
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.2:
  * Update translations.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.1:
  * Update translations.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.8.0:
  * Use a cario_surface to store thumbnails.
  * Fix GTK+ 3.20+ issues.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.2:
  * Update translations.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.6.1:
  * Update translations.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 1.6.0:
  * Switch zoom buttons in toolbar.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.4.5:
  * Update translations.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Update to version 1.4.4 (changes since 1.4.2):
  * Add support for image/x-fuji-raf raw files.
  * RAW images: Apply rotation to satisfy EXIF orientation.
- Require dcraw.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * Grid view: Activate item when pressing Space.
  * Improve keyboard navigation.
  * Update help to reflect keybinding changes.
  * Switch to symbolic icons.
  * Change default layout of thumbs to vertical in viewer-mode..
  * Make the screenshot button icon symbolic.
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.1 (changes since 1.2.1):
  * configure.ac: Fix a typo in message.
  * Build with webkit2gtk-4.0 instead of webkit2gtk-3.0.
  * Update translations.
- Remove pix-webkit2gtk.patch.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Update translations.
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Update translations.
* Fri Jul 15 2016 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Background extension: Add Xfce support.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.5 (changes since 1.0.2):
  * Fix thumbnails not being generated in browser/thumblist in
    GTK+ 3.18.
  * Fix pix crash in code selector.
  * Facebook: Add a permission to read user albums and photos.
  * Facebook: Fix authorisation process.
  * Update translations.
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Fix wrong URL in about dialog.
  * Toolbar: Show text under icons by default.
  * Fix setting background in MATE.
  * When setting backgrounds picture, don't mess with the options
    (picture aspect).
  * Remove a couple sizes of the palette.png icon.
  * Fix a build warning.
* Tue May 17 2016 sor.alexei@meowr.ru
- Initial package, based on gthumb's package.
